==> dss-plugin-sql-question-answering-tool-1.1.6.zip: CHANGELOG.md <==
# Changelog

## [Version 1.1.6] - Fix release - 2026-21-01
- Fix Snowflake Cortex LLMs issue
- Fix DATE_TRUNC / CAST issues

## [Version 1.1.5] - Fix release - 2025-12-01
- Fix DATEPART operator
- Fix SQL alias/prompt injection security issue

## [Version 1.1.4] - Fix release - 25-09-2025
- Update tool description
- Make distinct query more efficient when getting unique string column values for descriptions
- Fix issue with QUOTED_IDENTIFIERS_IGNORE_CASE enabled in Snowflake
- Fix cast issues

## [Version 1.1.3] - Fix release - 2025-09-05
- Fix run context issues due to shared kernel
- Fix a bug causing common table expressions (CTEs) to results in error when replacing Dataiku dataset names with table locations

## [Version 1.1.2] - Fix release - 2025-08-28
- Add workflow to update plugin on test instance run integration tests
- Add test script to test different permutations of parameters
- Changes to make metadata management safer for OpenAI Chat Completions API.
- Fixes to sql_mangement.py and tool.py based on review comments
- Add artifacts support

## [Version 1.1.1] - Fix release - 2025-07-02
- Fix SQL dataset fail check due to missing location info

## [Version 1.1.0] - Feature release - 2025-06-05
- Categorical column descriptions now automatically include all unique values for low cardinality columns
- Make command to make version releases with release notes
- Fix bug with get_descriptor being None

## [Version 1.0.0] - Feature release - 2025-06-02
- Add make commands to increase versions
- Reduced complexity of retry mechanism
- Add more detailed column and dataset descriptions
- Add pull request template

## [Version 0.0.5] - Fix release - 2025-05-30
- remove max on upper limit of SQl queries
- error messages no longer class attribute

## [Version 0.0.4] - Fix release - 2025-05-23
- add testing workflow
- add unit tests
- add linting checks
- add add ruff check

## [Version 0.0.3] - Fix release - 2025-05-21

- json parsing of response with regex
- sql hard limit: adds a LIMIT statement to each query run to avoid excessive quires
- retry mechanism for SQL query repair on error

## [Version 0.0.2] - Fix release - 2025-04-24

- Update agent tool description

## [Version 0.0.1] - Initial release 2025-02-09

- The agent tool "SQL Query" is able to answer questions related to the data contained in one or several SQL datasets.

==> dss-plugin-sql-question-answering-tool-1.3.0.zip: CHANGELOG.md <==
# Changelog

## [Version 1.3.0] - Feature/Fix release - 2026-21-01
- Support usage of caller ticket when calling the tool (`dkuCallerTicket` \ `TicketImpersonation`)
- Fix Snowflake Cortex LLMs issue
- Fix DATE_TRUNC / CAST issues

## [Version 1.2.0] - Fix release - 2025-12-01
- Fix datasets settings

## [Version 1.1.5] - Fix release - 2025-12-01
- Fix DATEPART operator
- Fix SQL alias/prompt injection security issue

## [Version 1.1.4] - Fix release - 25-09-2025
- Update tool description
- Make distinct query more efficient when getting unique string column values for descriptions
- Fix issue with QUOTED_IDENTIFIERS_IGNORE_CASE enabled in Snowflake
- Fix cast issues

## [Version 1.1.3] - Fix release - 2025-09-05
- Fix run context issues due to shared kernel
- Fix a bug causing common table expressions (CTEs) to results in error when replacing Dataiku dataset names with table locations

## [Version 1.1.2] - Fix release - 2025-08-28
- Add workflow to update plugin on test instance run integration tests
- Add test script to test different permutations of parameters
- Changes to make metadata management safer for OpenAI Chat Completions API.
- Fixes to sql_mangement.py and tool.py based on review comments
- Add artifacts support

## [Version 1.1.1] - Fix release - 2025-07-02
- Fix SQL dataset fail check due to missing location info

## [Version 1.1.0] - Feature release - 2025-06-05
- Categorical column descriptions now automatically include all unique values for low cardinality columns
- Make command to make version releases with release notes
- Fix bug with get_descriptor being None

## [Version 1.0.0] - Feature release - 2025-06-02
- Add make commands to increase versions
- Reduced complexity of retry mechanism
- Add more detailed column and dataset descriptions
- Add pull request template

## [Version 0.0.5] - Fix release - 2025-05-30
- remove max on upper limit of SQl queries
- error messages no longer class attribute

## [Version 0.0.4] - Fix release - 2025-05-23
- add testing workflow
- add unit tests
- add linting checks
- add add ruff check

## [Version 0.0.3] - Fix release - 2025-05-21

- json parsing of response with regex
- sql hard limit: adds a LIMIT statement to each query run to avoid excessive quires
- retry mechanism for SQL query repair on error

## [Version 0.0.2] - Fix release - 2025-04-24

- Update agent tool description

## [Version 0.0.1] - Initial release 2025-02-09

- The agent tool "SQL Query" is able to answer questions related to the data contained in one or several SQL datasets.
